==> lms-1.4.0rc1+libs.tar.gz: lms/lib/modules/example.class.php <==
<?

/*
 * LMS version 1.4.0rc1 Evalla
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: example.class.php,v 1.5.2.1 2004/09/18 19:14:50 alec Exp $
 */

/*
 * To jest przykadowa klasa modularna.
 * Taki zalk budowania moduw w LMS'ie.
 *
 * Klasa ta nic nie robi ani nie dziaa.
 */

class example
{
	// wersja moduu. moe by cokolwiek, byle by z sensem.
	// dla moduw LMS'a wersja to werjsa oglna LMS'a.
	
	var $_version = '1.4.0rc1 Evalla';

	// autor moduu. dla moduw standardowych 'LMS Developers'.
	
	var $_author = 'LMS Developers';

	// Opis. Krtki i zwizy.
	
	var $_description = 'Klasa przykadowa';

	// Rewizja pliku, o ile rozwijany by w CVS. Jeeli nie by,
	// to mona tutaj wpisa podwersj moduu. CORE i tak usuwa
	// tekst 'Revision:' oraz znaki $ z koca i pocztku linii,
	// za to zewntrzne moduy bd mogy sobie porwnywa te
	// wartoci aby sprawdzi poprawno moduw.

	var $_revision = '$Revision: 1.5.2.1 $';
	
	function example(&$core)
	{
		// do konstruktora klasy bdzie zawsze przekazywana referencja
		// do obiektu gnego LMS'a. Powinna ona by inicjowana w taki
		// oto sposb:
		
		$this->core = &$core;

		// Teraz odwoywanie si do gwne obiektu LMS'a powinno si
		// odbywa w sposb $this->core->funkcja(). Odwoanie do moduu
		// np. 'user', w sposb $this->core->user->funkcja(), chocia
		// cakiem moliwe e bdzie mona $this->user->funkcja().
		
		return TRUE;
	}

	function _postinit()
	{

		// funkcja ta bdzie wykonywana po zakoczeniu adowania
		// wszystkich moduw. tutaj kady modu moe sobie posprawdza
		// obecno innych moduw i ewentualnie ubi LMS'a jeeli wykryje
		// inny modu ;-)
	
		return TRUE;
	}
}

?>

==> lms-1.4.5+libs.tar.gz: lms/lib/modules/example.class.php <==
<?

/*
 * LMS version 1.4.5 Persus
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: example.class.php,v 1.5.2.2 2005/01/01 19:19:27 alec Exp $
 */

/*
 * To jest przykadowa klasa modularna.
 * Taki zalk budowania moduw w LMS'ie.
 *
 * Klasa ta nic nie robi ani nie dziaa.
 */

class example
{
	// wersja moduu. moe by cokolwiek, byle by z sensem.
	// dla moduw LMS'a wersja to werjsa oglna LMS'a.
	
	var $_version = '1.4.5 Persus';

	// autor moduu. dla moduw standardowych 'LMS Developers'.
	
	var $_author = 'LMS Developers';

	// Opis. Krtki i zwizy.
	
	var $_description = 'Klasa przykadowa';

	// Rewizja pliku, o ile rozwijany by w CVS. Jeeli nie by,
	// to mona tutaj wpisa podwersj moduu. CORE i tak usuwa
	// tekst 'Revision:' oraz znaki $ z koca i pocztku linii,
	// za to zewntrzne moduy bd mogy sobie porwnywa te
	// wartoci aby sprawdzi poprawno moduw.

	var $_revision = '$Revision: 1.5.2.2 $';
	
	function example(&$core)
	{
		// do konstruktora klasy bdzie zawsze przekazywana referencja
		// do obiektu gnego LMS'a. Powinna ona by inicjowana w taki
		// oto sposb:
		
		$this->core = &$core;

		// Teraz odwoywanie si do gwne obiektu LMS'a powinno si
		// odbywa w sposb $this->core->funkcja(). Odwoanie do moduu
		// np. 'user', w sposb $this->core->user->funkcja(), chocia
		// cakiem moliwe e bdzie mona $this->user->funkcja().
		
		return TRUE;
	}

	function _postinit()
	{

		// funkcja ta bdzie wykonywana po zakoczeniu adowania
		// wszystkich moduw. tutaj kady modu moe sobie posprawdza
		// obecno innych moduw i ewentualnie ubi LMS'a jeeli wykryje
		// inny modu ;-)
	
		return TRUE;
	}
}

?>
